@@ -13,9 +13,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: Shaun McCance  <shaunm@gnome.org>
  */
@@ -419,7 +417,7 @@ help_list_think (YelpHelpList *list)
                     const gchar *iconfile = gtk_icon_info_get_filename (info);
                     if (iconfile)
                         entry->icon = g_filename_to_uri (iconfile, NULL, NULL);
-                    gtk_icon_info_free (info);
+                    g_object_unref (info);
                 }
             }
             g_object_unref (app);
